!> \file output_anta_mod-0.4.f90
!! Module de
!<

!> \namespace output_antarcti_mod
!! Module de 
!! \author ...
!! \date ...
!! @note Used module
!! @note   - use module3D_phy
!<

module  output_antarcti_mod

use module3D_phy,only: xlong,ylat,b,s,acc,h,t,tbdot,ux,uy,uzk,uzsdot, &
              hdot,bdot,num_ritz,tafor,sealevel,ts
use geography, only: nx,ny,nz,geoplace,dirnameinp
use runparam, only: dirnameout,runname
use bilan_eau_mod
use netcdf
use io_netcdf_grisli
use bilan_flux_mod

implicit none
      
real ::  vol ; !integer :: np
integer :: nflot                      !< nbr de point flottant
real ::  bmean                        !<
real ::  accmean                      !< accumulation moyenne
real ::  ablmean                      !< ablation moyenne
real ::  calvmean                     !< moyenne calving
real ::  ablbordmean                  !<
real ::  bmeltmean                    !< moyenne fusion basale
real ::  tbmean                       !< temperature basale moyenne
real ::  tbdotmean                    !< moyenne variation / temps temperature basale
real ::  vsmean                       !< vitesse de surface moyenne
!real ::  vsdotmean                    !< moyenne variation / temps vitesse de surface
!real ::  uzsmean   !!!! utilise ?     !< vitesse verticale de surface moyenne
real ::  uzsdotmean                   !< moyenne variation / temps vitesse verticale de surface
real ::  uzkmean                      !< moyenne vitesse verticale de surface
real ::  hdotmean                     !< moyenne derivee / temps de h
real ::  bdotmean                     !< moyenne bedrock derive / temps
real ::  volf                         !< volume au dessus de la flottaison

real :: lim                           !< Total ice mass
real :: iareag                        !< surface posee
real :: iareaf                        !< surface flottante
real :: tendacabf                     !< Total SMB flux
real :: tendlibmassbf                 !< Total Basal mass balance flux
real :: tendlibmassbffl               !< Total Basal mass balance flux on floating ice
real :: tendlicalvf                   !< Total calving flux
real :: tendlifmassbf                 !< Total calving and ice front melting flux
real :: tendligroundf                 !< Total grounding line flux

real,dimension(nx,ny) :: corrsurf     !< facteur de correction de la surface
!real,parameter :: ice_density=910.    !< densite de la glace pour conversion en masse

! variables netcdf
integer,parameter :: ncshortout=1 ! 1 sorties netcdf short initMIP
integer,parameter :: nvar=10 ! nombre de variables dans le fichier de sortie temporel netcdf 
integer :: ncid
integer :: status
integer :: timeDimID
integer :: timeVarID
integer,dimension(nvar) :: varID
integer :: nbtimeout  ! index time output
real,dimension(nvar) :: var_shortoutput

! variables netcdf icecore (ic)
integer,parameter :: ncicecoreout=1 ! 1 sorties netcdf icecore / 0 no output
integer :: nbic ! number of ice core site in output
integer,parameter :: nvaric=10 ! nombre de variables dans le fichier ice core
real,parameter :: dticecoreout=50. ! sorties ice core tous les dticecoreout
integer :: ncidic
integer :: timeDimIDic
integer :: timeVarIDic
integer :: stationDimIDic
integer :: stationVarIDic
integer :: station_strlenDimIDic
integer :: lonVarIDic
integer :: latVarIDic
integer,dimension(nvaric) :: varIDic
integer :: nbtimeoutic  ! index time output
real,allocatable,dimension(:,:) :: var_icoutput
character(len=100), allocatable, dimension(:) :: site_nameic
integer, allocatable, dimension(:) :: iic,jic ! coordonnees i,j des sites ice core

CONTAINS

subroutine init_outshort

double precision,dimension(:,:),pointer      :: tab               !< tableau 2d real pointer
character(len=100),dimension(nvar) :: namevar ! name, standard_name, long_name, units
character(len=100),dimension(nvar) :: standard_name
character(len=100),dimension(nvar) :: long_name
character(len=100),dimension(nvar) :: units

! ice core variables
character(len=100),allocatable,dimension(:) :: ic_name ! ice core name
real,allocatable,dimension(:) :: ic_lon ! ice core lon
real,allocatable,dimension(:) :: ic_lat ! ice core lat
character(len=100),dimension(nvaric) :: namevaric ! name, standard_name, long_name, units
character(len=100),dimension(nvaric) :: standard_nameic
character(len=100),dimension(nvaric) :: long_nameic
character(len=100),dimension(nvaric) :: unitsic
integer :: err ! recuperation erreur
integer :: ii,jj
integer :: nloop ! nbr de tour dans la boucle while (evite boucle folle)
real :: dist_lonlat, dist_lonlat_new, distance ! distance to lon lat ice core site
integer :: i,j,k,l




if (ncshortout.eq.1) then  ! ecriture netcdf

! lecture du fichier avec les corrections de surface
  if (geoplace.eq.'ant16km') then
      call Read_Ncdf_var('z',trim(DIRNAMEINP)//'/corrsurf-initMIP-16km.grd',tab)
      corrsurf(:,:)=tab(:,:)
  else
      corrsurf(:,:)= 1.
  end if

  open(568,file=trim(dirsource)//'/Fichiers-parametres/short-ISMIPnc.dat',status='old')
! lecture en-tete
  read(568,*)
  read(568,*)
  read(568,*)
  read(568,*)
  read(568,*)
! lecture des infos sur les variables :
  do k=1,nvar
    read(568,'(a100)') namevar(k)
    read(568,'(a100)') standard_name(k)
    read(568,'(a100)') long_name(k)
    read(568,'(a100)') units(k)
    read(568,*)
  enddo
  close(568)
  
! Fichier Netcdf initMIP
! creation du fichier Netcdf :
  status=nf90_create(path = trim(dirnameout)//'short'//runname//'.nc', cmode = nf90_clobber, ncid = ncid)
  if (status /= nf90_noerr) call handle_err(status)

! definition des dimension :
  status=nf90_def_dim(ncid, name="time", len=NF90_UNLIMITED, dimid=timeDimID)
  if (status /= nf90_noerr) call handle_err(status)
  status=nf90_def_var(ncid, name="time", xtype=nf90_float, dimids=(/ timeDimID/), varid=timeVarID) 
  if (status /= nf90_noerr) call handle_err(status)
  status=nf90_put_att(ncid, timeVarID, "standard_name", "time")
  if (status /= nf90_noerr) call handle_err(status)
  status=nf90_put_att(ncid, timeVarID,"units", "years since 1995-01-01 00:00:00")
  if (status /= nf90_noerr) call handle_err(status)
  status=nf90_put_att(ncid, timeVarID,"calendar", "360_day")
  if (status /= nf90_noerr) call handle_err(status)
  
! definition des variables de sortie :
  do k=1,nvar  ! boucle sur le nbr de variable a definir
    status=nf90_def_var(ncid, name=trim(namevar(k)), xtype=nf90_float, dimids= &
          (/ timeDimID /), varid=varID(k))
    if (status /= nf90_noerr) call handle_err(status)
    status=nf90_put_att(ncid, varID(k), "standard_name", trim(standard_name(k)))
    if (status /= nf90_noerr) call handle_err(status)
    status=nf90_put_att(ncid, varID(k), "long_name", trim(long_name(k)))
    if (status /= nf90_noerr) call handle_err(status)
    status=nf90_put_att(ncid, varID(k), "units", trim(units(k)))
    if (status /= nf90_noerr) call handle_err(status)
  enddo

! fin de la definition du fichier :
  status=nf90_enddef(ncid)
  if (status /= nf90_noerr) call handle_err(status)
  nbtimeout = 0 ! initialisation compteur sorties axe time
else ! pas de sortie netcdf et sans correction de surface
  corrsurf(:,:)=1.
endif


if (ncicecoreout.eq.1) then  ! ecriture netcdf Ice Core
! Fichier Netcdf ice core Antarctique
! Lecture du fichier avec la liste des sites de forages
! infos sur les variables :
  open(568,file=trim(dirsource)//'/Fichiers-parametres/icecore-Ant.dat',status='old')
  ! lecture en-tete
  read(568,*)
  read(568,*)
  read(568,*)
  read(568,*)
  read(568,*)
  ! lectuire du nombre de sites de forages:
  read(568,*) nbic
  read(568,*)
  ! allocation des variables dependant du nombre de site de forage (nbic)
  if (.not.allocated(iic)) then
     allocate(iic(nbic),stat=err)
     if (err/=0) then
        print *,"erreur a l'allocation du tableau iic dans init_outshort",err
        stop 4
     end if
  end if
  if (.not.allocated(jic)) then
     allocate(jic(nbic),stat=err)
     if (err/=0) then
        print *,"erreur a l'allocation du tableau jic dans init_outshort",err
        stop 4
     end if
  end if
  if (.not.allocated(ic_name)) then
     allocate(ic_name(nbic),stat=err)
     if (err/=0) then
        print *,"erreur a l'allocation du tableau ic_name dans init_outshort",err
        stop 4
     end if
  end if
  if (.not.allocated(ic_lon)) then
     allocate(ic_lon(nbic),stat=err)
     if (err/=0) then
        print *,"erreur a l'allocation du tableau ic_lon dans init_outshort",err
        stop 4
     end if
  end if
  if (.not.allocated(ic_lat)) then
     allocate(ic_lat(nbic),stat=err)
     if (err/=0) then
        print *,"erreur a l'allocation du tableau ic_lat dans init_outshort",err
        stop 4
     end if
  end if
  if (.not.allocated(var_icoutput)) then
     allocate(var_icoutput(nbic,nvaric),stat=err)
     if (err/=0) then
        print *,"erreur a l'allocation du tableau var_icoutput dans init_outshort",err
        stop 4
     end if
  end if
! lecture des infos sur les variables :
  do k=1,nbic
     read(568,'(a100)') ic_name(k)
     !ic_name(k)=trim(ic_name(k))
     read(568,*) ic_lon(k)
     read(568,*) ic_lat(k)
     read(568,*)
  enddo
 close(568)
 ! recherche du point i,j correspondant aux coordonnées lon,lat de chaque site de forage
 do k=1,nbic
    dist_lonlat = 1.e7 ! initialisation
    dist_lonlat_new = 1.e6 ! initialisation
    ! on part du centre de la grille
    !    iic(k)=int(nx/2)
    !    jic(k)=int(ny/2)
    iic(k)=6
    jic(k)=6
    nloop=0
    do while (dist_lonlat_new .LT. dist_lonlat .AND. nloop .LT. 10000)
       nloop=nloop+1
       dist_lonlat = dist_lonlat_new
       ii = iic(k)
       jj = jic(k)
       do j=max(jj-5,1),min(jj+5,ny)
          do i=max(ii-5,1),min(ii+5,nx)
             distance = abs(xlong(i,j) - ic_lon(k)) + abs(ylat(i,j) - ic_lat(k))
             if (distance .LT. dist_lonlat) then
                dist_lonlat_new = distance
                iic(k) = i
                jic(k) = j
             endif
          enddo
       enddo
    enddo
    !print*,'init_outshort : ice core ', trim(ic_name(k)), nloop
    !print*,'init_outshort lon,lat', ic_lon(k),ic_lat(k)
    !print*,'init_outshort i,j',iic(k),jic(k)
    !print*,'init_outshort lon lat GRISLI',xlong(iic(k),jic(k)),ylat(iic(k),jic(k))
 enddo           
          


! creation du fichier Netcdf :
  status=nf90_create(path = trim(dirnameout)//'icecore'//runname//'.nc', cmode = nf90_clobber, ncid = ncidic)
  if (status /= nf90_noerr) call handle_err(status)

  ! definition des dimension :
  status=nf90_def_dim(ncidic, name="time", len=NF90_UNLIMITED, dimid=timeDimIDic)
  if (status /= nf90_noerr) call handle_err(status)
  status=nf90_def_var(ncidic, name="time", xtype=nf90_float, dimids=(/ timeDimIDic/), varid=timeVarIDic) 
  if (status /= nf90_noerr) call handle_err(status)
  status=nf90_put_att(ncidic, timeVarIDic, "standard_name", "time")
  if (status /= nf90_noerr) call handle_err(status)
  status=nf90_put_att(ncidic, timeVarIDic,"units", "years")
  if (status /= nf90_noerr) call handle_err(status)
  status=nf90_put_att(ncidic, timeVarIDic,"calendar", "360_day")
  if (status /= nf90_noerr) call handle_err(status)
  
  ! dimension "station" Sites de forages
  status=nf90_def_dim(ncidic, name="station", len=nbic, dimid=stationDimIDic)
  if (status /= nf90_noerr) call handle_err(status)
  status=nf90_def_dim(ncidic, name="name_strlen", len=len(ic_name(1)), dimid=station_strlenDimIDic)
  if (status /= nf90_noerr) call handle_err(status)
  status=nf90_def_var(ncidic, name="station_name", xtype=nf90_char, dimids=(/ station_strlenDimIDic, stationDimIDic /), varid=stationVarIDic) 
  if (status /= nf90_noerr) call handle_err(status)
  status=nf90_put_att(ncidic, stationVarIDic, "standard_name", "station_name")
  if (status /= nf90_noerr) call handle_err(status)
  status=nf90_put_att(ncidic, stationVarIDic, "long_name", "station name")
  if (status /= nf90_noerr) call handle_err(status)
  status=nf90_def_var(ncidic, name="lon", xtype=nf90_float, dimids=(/ stationDimIDic/), varid=lonVarIDic) 
  if (status /= nf90_noerr) call handle_err(status)
  status=nf90_put_att(ncidic, lonVarIDic, "standard_name", "longitude")
  if (status /= nf90_noerr) call handle_err(status)
  status=nf90_put_att(ncidic, lonVarIDic, "long_name", "station longitude")
  if (status /= nf90_noerr) call handle_err(status)
  status=nf90_def_var(ncidic, name="lat", xtype=nf90_float, dimids=(/ stationDimIDic/), varid=latVarIDic) 
  if (status /= nf90_noerr) call handle_err(status)
  status=nf90_put_att(ncidic, latVarIDic, "standard_name", "latitude")
  if (status /= nf90_noerr) call handle_err(status)
  status=nf90_put_att(ncidic, latVarIDic, "long_name", "station latitude")
  if (status /= nf90_noerr) call handle_err(status)

  
! infos sur les variables :
  open(568,file=trim(dirsource)//'/Fichiers-parametres/icecore-var.dat',status='old')
! lecture en-tete
  read(568,*)
  read(568,*)
  read(568,*)
  read(568,*)
  read(568,*)
! lecture des infos sur les variables :
  do l=1,nvaric
    read(568,'(a100)') namevaric(l)
    read(568,'(a100)') standard_nameic(l)
    read(568,'(a100)') long_nameic(l)
    read(568,'(a100)') unitsic(l)
    read(568,*)
 enddo
 close(568)
  
! definition des variables de sortie :
  do l=1,nvaric  ! boucle sur le nbr de variable a definir
    status=nf90_def_var(ncidic, name=trim(namevaric(l)), xtype=nf90_float, dimids= &
          (/ stationDimIDic, timeDimIDic /), varid=varIDic(l))
    if (status /= nf90_noerr) call handle_err(status)
    status=nf90_put_att(ncidic, varIDic(l), "standard_name", trim(standard_nameic(l)))
    if (status /= nf90_noerr) call handle_err(status)
    status=nf90_put_att(ncidic, varIDic(l), "long_name", trim(long_nameic(l)))
    if (status /= nf90_noerr) call handle_err(status)
    status=nf90_put_att(ncidic, varIDic(l), "units", trim(unitsic(l)))
    if (status /= nf90_noerr) call handle_err(status)
  enddo

! fin de la definition du fichier :
  status=nf90_enddef(ncidic)
  if (status /= nf90_noerr) call handle_err(status)
  
  nbtimeoutic = 0 ! initialisation compteur sorties axe time
  ! ecriture des noms des sites de forage dans la variable site :
!  do k=1,nbic
!     status=nf90_put_var(ncidic, stationVarIDic, trim(ic_name(k)),start=(/k/),count=(/1/))
!     if (status /= nf90_noerr) call handle_err(status)
!  enddo
  !print*,'ic_name',ic_name   
  status=nf90_put_var(ncidic, stationVarIDic, ic_name) !,start=(/1/),count=(/nbic/))
  if (status /= nf90_noerr) call handle_err(status)

  status=nf90_put_var(ncidic, lonVarIDic, ic_lon,start=(/1/),count=(/nbic/))
  if (status /= nf90_noerr) call handle_err(status)
     
  status=nf90_put_var(ncidic, latVarIDic, ic_lat,start=(/1/),count=(/nbic/))
  if (status /= nf90_noerr) call handle_err(status)
!     print*, 'debug 2 init_outshort'
endif



end subroutine init_outshort



!_________________________________________________________________________
subroutine shortoutput

! 1_initialization
!------------------
real ::  smax,hmax,hmean
integer :: np,i,j,k,l

      vol=0. 
      np=0
      nflot=0
      hmax=0. 
      smax=0.
      bmean=0. 
      accmean=0. 
      ablmean=0. 
      calvmean=0.  
      ablbordmean=0.
      bmeltmean=0.
      tbmean=0.
      tbdotmean=0.
      vsmean=0.
!      vsdotmean=0.
!      uzsmean=0.
      uzsdotmean=0.
      uzkmean=0.
      hdotmean=0.
      bdotmean=0.
      volf=0.
      lim=0.
      tendacabf=0.
      iareag=0.
      iareaf=0.
      tendlicalvf=0.
      tendligroundf=0.
      tendlibmassbf=0.
      tendlibmassbffl=0.
      tendlifmassbf=0.
! 2_preparing outputs
!--------------------      
    do j=1,ny
      do i=1,nx
        if (ice(i,j).eq.1) then ! point englace
          if (.not.flot(i,j)) then ! point pose 
            np=np+1
            vol=vol+h(i,j)
            iareag=iareag+1.*corrsurf(i,j)                            ! surface englacee posee

!         calcul de la hauteur au dessus de la flottaison
            if (sealevel_2d(i,j)-B(i,j).le.0.) then    ! socle au dessus du niveau des mers
              volf=volf+h(i,j)*corrsurf(i,j)                          ! volume au-dessus de la flottaison
            else
              volf=volf+(h(i,j)-row/ro*(sealevel_2d(i,j)-b(i,j)))*corrsurf(i,j) ! volume au-dessus de la flottaison
            endif

            if (h(i,j).gt.hmax) hmax=h(i,j) 
            if (s(i,j).gt.smax) smax=s(i,j) 
            bmean=bm(i,j)+bmean 
            accmean=acc(i,j)+accmean
            tbmean=tbmean+t(i,j,nz)
            tbdotmean=tbdotmean+tbdot(i,j)
            vsmean=vsmean+sqrt(ux(i,j,1)**2+uy(i,j,1)**2)
!          vsdotmean=vsdotmean+vsdot(i,j)
!          uzsmean=uzsmean+uz(i,j,1)
            uzsdotmean=uzsdotmean+uzsdot(i,j)
            uzkmean=uzkmean+uzk(i,j)
            hdotmean=hdotmean+abs(hdot(i,j)) 
            bdotmean=bdotmean+abs(bdot(i,j)) 
            bmeltmean=bmeltmean+bmelt(i,j)
          else ! point flottant
            iareaf=iareaf+1.*corrsurf(i,j)                               ! surface flottante
            tendlibmassbffl=tendlibmassbffl-bmelt_dtt(i,j)*corrsurf(i,j)/dtt_flux   ! fonte basale sur zone flottante
          endif
          lim=lim+h(i,j)*corrsurf(i,j)                                   ! volume total de glace
          tendacabf=tendacabf+bm_dtt(i,j)*corrsurf(i,j)/dtt_flux              ! smb surface
          tendlibmassbf=tendlibmassbf-bmelt_dtt(i,j)*corrsurf(i,j)/dtt_flux   ! fonte basale     
        endif
        tendlicalvf=tendlicalvf+calv_dtt(i,j)*corrsurf(i,j)/dtt_flux        ! calving
        tendlifmassbf=tendlifmassbf+(calv_dtt(i,j)-ablbord_dtt(i,j))*corrsurf(i,j)/dtt_flux ! calving + ablbord (ablbord est positif)
        tendligroundf=tendligroundf+grline_dtt(i,j)*corrsurf(i,j)/dtt_flux  ! flux a la grounding line
      end do
    end do


      if (np.ne.0) then 
        hmean=vol/np 
        vol=vol*dx*dy 
        volf=volf*dx*dy*ice_density
        bmean=bmean/np 
        accmean=accmean/np 
        ablmean=bmean-accmean 
        calvmean=calvmean/np 
        bmeltmean=bmeltmean/np
        ablbordmean=ablbordmean/np
        tbmean=tbmean/np
        tbdotmean=tbdotmean/np
        vsmean=vsmean/np
!        vsdotmean=vsdotmean/np
!        uzsmean=uzsmean/np
        uzsdotmean=uzsdotmean/np
        uzkmean=uzkmean/np
        hdotmean=hdotmean/np
      endif
      lim=lim*dx*dy*ice_density
      iareag=iareag*dx*dy 
      iareaf=iareaf*dx*dy
      tendacabf=tendacabf*dx*dy*ice_density/secyear
      tendlibmassbf=tendlibmassbf*dx*dy*ice_density/secyear
      tendlibmassbffl=tendlibmassbffl*dx*dy*ice_density/secyear
      tendlicalvf=tendlicalvf*dx*dy*ice_density/secyear
      tendlifmassbf=tendlifmassbf*dx*dy*ice_density/secyear
      tendligroundf=tendligroundf*ice_density/secyear
      
      
      bdotmean=bdotmean/nx/ny  


! 2_writing outputs
!------------------    
!     **** short display **** 

        write(num_ritz,904) nt,time,tafor,sealevel,vol,volf,np, &
          nint(hmean),nint(smax),                    &
          bmean,tbmean,nint(vsmean),                 &
				  tbdotmean,hdotmean,dt,accmean, &
				  diff_H,water_bilan,sum(calv_dtt(:,:))/dtt_flux, &
				  sum(ablbord_dtt(:,:))/dtt_flux, &
				  sum(Bm_dtt(:,:))/dtt_flux,sum(bmelt_dtt(:,:))/dtt_flux


903   format(i8,1x,f0.2,1x,f0.4,1x,f0.2,1x,2(e10.5,1x),i6,1x,i4,1x,i5,1x, &
             f0.4,1x,f0.3,1x,i3,4(1x,e8.2),1x,f0.4,1x,f0.4) 
904   format(i8,1x,f0.2,4(1x,e15.8),3(1x,i8),2(1x,e15.8),1x,i8,10(1x,e15.8))
!940   format('%%%% ',a,'   time=',f8.0,' %%%%')


if (ncshortout.eq.1) then  ! ecriture netcdf
  ! Total ice mass
  var_shortoutput(1)=lim
  ! Mass above floatation
  var_shortoutput(2)=volf
  ! Grounded ice area
  var_shortoutput(3)=iareag
  ! Floating ice area
  var_shortoutput(4)=iareaf
  ! Total SMB flux 
  var_shortoutput(5)=tendacabf
  ! Total Basal mass balance flux
  var_shortoutput(6)=tendlibmassbf
  ! Total Basal mass balance flux beneath floating ice
  var_shortoutput(7)=tendlibmassbffl
  ! Total calving flux 
  var_shortoutput(8)=tendlicalvf
  ! Total calving and ice front melting flux
  var_shortoutput(9)=tendlifmassbf
  ! Total grounding line flux
  var_shortoutput(10)=tendligroundf

  nbtimeout=nbtimeout+1
  
  status=nf90_put_var(ncid, timeVarID, time, start=(/nbtimeout/))
  if (status /= nf90_noerr) call handle_err(status)

  do k=1,nvar  ! boucle sur le nbr de variable a ecrire
    status=nf90_put_var(ncid, varID(k), var_shortoutput(k),start=(/nbtimeout/))
    if (status /= nf90_noerr) call handle_err(status)
  enddo
  status=nf90_sync(ncid)
  if (status /= nf90_noerr) call handle_err(status)
endif


! ecriture netcdf ice core output (tous les 50 ans)
if (ncicecoreout.eq.1 .and. (mod(abs(time),dticecoreout).lt.dtmin)) then  ! ecriture netcdf
   nbtimeoutic=nbtimeoutic+1
   do k=1,nbic ! boucle sur les stations
      ! Surface elevation
      var_icoutput(k,1)=S(iic(k),jic(k))
      ! Ice thickness
      var_icoutput(k,2)=H(iic(k),jic(k))
      ! Bedrock elevation
      var_icoutput(k,3)=Bsoc(iic(k),jic(k))
      ! Surface Mass Balance
      var_icoutput(k,4)=Bm(iic(k),jic(k))
      ! Basal melt
      var_icoutput(k,5)=Bmelt(iic(k),jic(k))
      ! Surface velocity in x
      var_icoutput(k,6)=Uxbar(iic(k),jic(k))
      ! Surface velocity in y
      var_icoutput(k,7)=Uybar(iic(k),jic(k))
      ! Velocity magnitude
      var_icoutput(k,8)=sqrt(Uxbar(iic(k),jic(k))**2 + Uybar(iic(k),jic(k))**2)
      ! Surface Temperature
      var_icoutput(k,9)=Ts(iic(k),jic(k))
      ! Accumulation
      var_icoutput(k,10)=Acc(iic(k),jic(k))
   enddo
  ! ecriture de time
   status=nf90_put_var(ncidic, timeVarIDic, time, start=(/nbtimeoutic/))
   if (status /= nf90_noerr) call handle_err(status)
   
   do l=1,nvaric  ! boucle sur le nbr de variables a ecrire
      status=nf90_put_var(ncidic, varIDic(l), var_icoutput(:,l),start=(/1,nbtimeoutic/))
      if (status /= nf90_noerr) call handle_err(status)
   enddo
   status=nf90_sync(ncidic)
   if (status /= nf90_noerr) call handle_err(status)
endif



end subroutine shortoutput

subroutine handle_err(status)
  integer, intent(in) :: status
  if (status /= nf90_noerr) then
     print*,trim(nf90_strerror(status))
     stop "stopped"
  end if
end subroutine handle_err

end module  output_antarcti_mod
