!> \file initial-phy-2.f90
!! Initialisation des parametres physique du modele
!<

!> SUBROUTINE: initial_phy
!! Subroutine qui initialise les parametres physique du modele
!! \author ...
!! \date ...
!! @note Used modules:
!! @note    - module3D_phy
!!
!<
subroutine initial_phy

  !     **************************************************
  !     **         initialisation                        *
  !     *                                                *
  !     **************************************************

  use module3D_phy, only:icompteur,iout,reprcptr,igrdline,schoof,ibmelt_inv,dtmin,dtmax,&
       dtt,testdiag,num_param,num_rep_42,num_ritz,dt,ntmax,time,tafor,sealevel,&
       sealevel_2d,secyear,isynchro
  use geography, only: geoplace
  use runparam, only :runname,itracebug,num_tracebug,tbegin,tend,dirsource,dirnameout,dttest,&
       nt


  implicit none

  character(len=80) :: filin
  character(len=80) :: comment_run

  namelist/runpar/runname,icompteur,iout,reprcptr,itracebug,num_tracebug,comment_run
  namelist/grdline/igrdline,Schoof,ibmelt_inv
  namelist/timesteps/dtmin,dtmax,dtt,testdiag,tbegin,tend


  ! ouverture du fichier parametre ..._param_list.dat
  !--------------------------------------------------------------
  dirsource='../SOURCES'
  filin=trim(geoplace)//'_param_list.dat'

  open(num_param,file=filin) 


  ! lecture des parametres du run                          block runpar
  !--------------------------------------------------------------------

  rewind(num_param)        ! pour revenir au debut du fichier param_list.dat
  read(num_param,runpar)

!  filin='../Param/param'//runname
  filin='param'//runname
  open(num_rep_42,file=filin)

  ! reecriture des parametres entres dans le fichier 42
  !------------------------------------------------------
  write(num_rep_42,*)'!  Parametres du run :',runname, '    ',geoplace
  write(num_rep_42,*)'!  sources dans  ',trim(dirsource)
  write(num_rep_42,*)
  write(num_rep_42,'(A)')'!___________________________________________________________' 
  write(num_rep_42,'(A)') '&runpar                  ! nom du bloc  parametres du run'
  write(num_rep_42,*)
  write(num_rep_42,*) 'runname      =  "',runname,'"'
  write(num_rep_42,*) 'icompteur    = ', icompteur                              
  write(num_rep_42,*) 'iout         = ', iout 
  write(num_rep_42,*) 'reprcptr     = "',trim(reprcptr),'"'
  write(num_rep_42,*) 'itracebug    = ', itracebug
  write(num_rep_42,*) 'num_tracebug  = ', num_tracebug
  write(num_rep_42,*) 'comment_run   = "',trim(comment_run),'"'
  write(num_rep_42,*)'/'                            
  write(num_rep_42,'(A)') '! runname    : nom de l experience (8 caracteres)  '
  write(num_rep_42,'(A)') '! icompteur  : reprise dans un fichier  0 -> non, 1 -> oui, 2 -> T et Hw'
  write(num_rep_42,'(A)') '! icompteur  : 3-> T seulement'
  write(num_rep_42,'(A)') '! iout   : 1-> sortie cptr pour reprise,2 -> sortie nc pour reprise '
  write(num_rep_42,'(A)') '! reprcptr   : nom du fichier restart'
  write(num_rep_42,'(A)') '! itracebug: 1-> ecriture de traces au debut des routines'
  write(num_rep_42,'(A)') '! num_tracebug   numero d unite ecriture traces'
  write(num_rep_42,'(A)') '! comment_run: commentaire court sur le run'

  write(num_rep_42,*)


  write(6,*)'_________________________________________________'
  write(6,*)'runname=',runname


  ! ouverture du fichier short
  !------------------------------


  filin='short'//runname//'.ritz'
  filin=TRIM(DIRNAMEOUT)//TRIM(filin)

  open(num_ritz,file=filin)



  ! lecture des parametres du run                          block grdline
  !--------------------------------------------------------------------


  rewind(num_param)        ! pour revenir au debut du fichier param_list.dat
  read(num_param,grdline)


  write(num_rep_42,'(A)')'!___________________________________________________________'  
  write(num_rep_42,'(A)') '&grdline                 ! bloc grounding line'
  write(num_rep_42,*)
  write(num_rep_42,*) 'igrdline     = ',igrdline
  write(num_rep_42,*) 'Schoof       = ',Schoof
  write(num_rep_42,*) 'ibmelt_inv   = ',ibmelt_inv
  write(num_rep_42,*)'/'                           
  write(num_rep_42,'(A)')'! igrdline   : 1 ligne d echouage fixe, sinon 0'
  write(num_rep_42,'(A)')'! Schoof     : 0 pas de Schoof, 1 flux de Schoof'
  write(num_rep_42,'(A)')'! ibmelt_inv : 0 cas std, 1 inversion du bmelt (avec igrdline=1)'
  write(num_rep_42,*)


  ! lecture des parametres du run                          block timesteps
  !-----------------------------------------------------------------------
  rewind(num_param)        ! pour revenir au debut du fichier param_list.dat
  read(num_param,timesteps)

  write(num_rep_42,'(A)')'!___________________________________________________________'  
  write(num_rep_42,'(A)') '&timesteps                 ! bloc time steps'
  write(num_rep_42,*)
  write(num_rep_42,*) 'tend      = ',tend
  write(num_rep_42,*) 'tbegin    = ',tbegin
  write(num_rep_42,*) 'dtmin     = ',dtmin
  write(num_rep_42,*) 'dtmax     = ',dtmax
  write(num_rep_42,*) 'dtt       = ',dtt
  write(num_rep_42,*) 'testdiag  = ',testdiag


  write(num_rep_42,*)'/'                           
  write(num_rep_42,'(A)')'! tous les temps en annees. tbegin et tend : debut et fin du run '
  write(num_rep_42,'(A)')'! pour equation masse, pas de temps mini -> dtmin, maxi -> dtmax'      
  write(num_rep_42,'(A)')'! dtt : pas de temps long'
  write(num_rep_42,'(A)')'! testdiag, pour grer le pas de temps dynamique dt'
  write(num_rep_42,'(A)')'! ordres de grandeur (a moduler selon dx) : '
  write(num_rep_42,'(A)')'! 40 km dtmin=2.e-2, dtmax=1., dtt=5., tesdiag=0.02'

  write(num_rep_42,*)


  !      si shelf rapide
  !        testdiag=0.016

  !---------------------------------------------------------------------
  dt=dtmin           ! sera rattribue a chaque pas de temps
  ntmax=90000000     ! nombre de tours maxi dans la boucle temps
  dttest=dtmin       ! sert dans plein de tests 
  time=tbegin 
  nt=-1



  ! ----------------parametres dont le traitement en namelist est remis a plus tard


  ! Tous les parametres lis  l'ablation devraient tre dans un module ablation
  ! A changer plus tard

  !     temperature forcing : annual, july. 
  TAFOR=0.
  SEALEVEL=0.0
  sealevel_2d(:,:)=0.

!  SECYEAR=365.*24.*3600.
  secyear= 31556926 ! s /an

  !--------------------- 

  !     switch 
  isynchro=0


end subroutine initial_phy
